# captif-data-structures

Python package to keep track of the various data files and file versions used by CAPTIF Road Research. The package includes reader classes for general data types.

The following data types are currently supported.

CAPTIF facility:
- lap count

Instruments:
 - deflection beam
 - stationary laser profilometer (SLP)

Examples of the data structures currently supported can be found in `./tests/data`.